@@ -4,7 +4,7 @@ use warnings;
 use strict;
 use 5.10.0;
 
-our $VERSION = '1.762';
+our $VERSION = '1.764';
 
 use Exporter qw( import );
 
@@ -741,9 +741,7 @@ sub table_char_width { [
 [  0x2ef4,   0x2eff, 1],
 [  0x2f00,   0x2fd5, 2],
 [  0x2fd6,   0x2fef, 1],
-[  0x2ff0,   0x2ffb, 2],
-[  0x2ffc,   0x2fff, 1],
-[  0x3000,   0x3029, 2],
+[  0x2ff0,   0x3029, 2],
 [  0x302a,   0x302d, 0],
 [  0x302e,   0x303e, 2],
 [  0x303f,   0x3040, 1],
@@ -757,8 +755,8 @@ sub table_char_width { [
 [  0x3131,   0x318e, 2],
 [  0x318f,   0x318f, 1],
 [  0x3190,   0x31e3, 2],
-[  0x31e4,   0x31ef, 1],
-[  0x31f0,   0x321e, 2],
+[  0x31e4,   0x31ee, 1],
+[  0x31ef,   0x321e, 2],
 [  0x321f,   0x321f, 1],
 [  0x3220,   0x4dbf, 2],
 [  0x4dc0,   0x4dff, 1],
@@ -839,7 +837,8 @@ sub table_char_width { [
 [  0xabed,   0xabed, 0],
 [  0xabee,   0xabff, 1],
 [  0xac00,   0xd7a3, 2],
-[  0xd7a4,   0xd7ff, 1],
+[  0xd7a4,   0xd7af, 1],
+[  0xd7b0,   0xd7ff, 0],
 #[  0xd800,   0xdfff, -1],
 [  0xe000,   0xfaff, 2],
 [  0xfb00,   0xfb1d, 1],
